emit_doc

Function emit_doc 

pub fn emit_doc(
    out: &mut String,
    doc: &Option<String>,
    indent: &str,
    style: DocCommentStyle,
)
Emit a doc comment for doc at the given indent, using the given style. No-op when doc is None or trims to empty.

The output always ends with a trailing newline so a generator can follow it directly with the symbol declaration on the next line.